function [z,A] = newton(f, fprime, x0, tau)
%Aufruf: [z,A] = newton(f, fprime, x0, tau)
%Parameter: z ... Nherungswert der Nullstelle
%       A ... Matrix der Nherungswerte
%       f ... Function-Handle
%       fprime ... Function-Handle der 1. Ableitung von f
%       x0 ... Startwert
%       tau ... Toleranz
%Funktionsweise: Das Newton-Verfahren wird durchgefhrt.

if (abs(x0)<=tau)
    cond = tau;
else
    cond = tau * abs(x0);
end

A(1,1:2)=[x0 f(x0)];

xneu=x0;
while (abs(f(xneu))>tau || abs(xneu-x0)>cond)
    %Abbruchbedingung prfen
    if (abs(fprime(xneu))<=tau)
        fprintf(2, 'FEHLER! Die Operation wird abgebrochen.\n');
        xneu=NaN;
        break;
    end
    
    %Startwerte neu festlegen
    x0=xneu;
    
    %Nullstelle der neuen Tangente berechnen
    xneu=xneu-f(xneu)/fprime(xneu);
    A(size(A,1)+1,1:2)=[xneu f(xneu)];

    if (abs(xneu)<=tau)
        cond = tau;
    else
        cond = tau * abs(xneu);
    end
 
end
z=xneu;
end