function [z,A] = sekante(f, x0, x1, tau)
%Aufruf: [z,A] = sekante(f, x0, x1, tau)
%Parameter: z ... Nherungswert der Nullstelle
%       A ... Matrix der Nherungswerte
%       f ... Function-Handle
%       x0, x1 ... Startwerte
%       tau ... Toleranz
%Funktionsweise: Das Sekantenverfahren wird durchgefhrt.

if (abs(x1)<=tau)
    cond = tau;
else
    cond = tau * abs(x1);
end
A(1:2,1:2)=[x0 f(x0); x1 f(x1)];

while (abs(f(x1))>tau || abs(x1-x0)>cond)
    %Abbruchbedingung prfen
    if (abs(f(x1)-f(x0))<=tau)
        fprintf(2, 'FEHLER! Die Operation wird abgebrochen.\n');
        xneu=NaN;
        break;
    end
    
    %Nullstelle der neuen Sekante berechnen
    xneu=x1-f(x1)*(x0-x1)/(f(x0)-f(x1));
    A(size(A,1)+1,1:2)=[xneu f(xneu)];

    if (abs(xneu)<=tau)
        cond = tau;
    else
        cond = tau * abs(xneu);
    end
    
    %Startwerte neu festlegen
    x0=x1;
    x1=xneu;
 
end
z=xneu;
end